# -*- coding: utf8 -*-

import logger
import requests
import wdcommon
from artix.common.servicelock import ServiceLock
from time import sleep

log = logger.getLogger()


def checkLoadRequired(host, port, cashCode):
    """
    Функция проверки необходимости загрузки справочников
    :param host - порт REST сервера
    :param port - порт REST сервера
    :param cashCode - код кассы
    """
    log.info(u"Получение количества сообщений в очереди на сервере")
    requestUrl = "http://%s:%s/CSrest/rest/queue/%s/messages/count" % (host, port, cashCode)
    log.info(requestUrl)

    with requests.Session() as session:
        response = session.get(requestUrl, timeout=60)
        log.debug(response.content)
        jsonResponse = response.json()

    errorMessage = u"Ошибка получения количества сообщений в очереди"

    if response.status_code == requests.codes.ok:
        messagesCount = int(response.content)
        if messagesCount > 0:
            log.info(u"Количество сообщений в очереди на сервере: %s" % messagesCount)
            return True
        log.info(u"В очереди нет сообщений")
        return False
    elif response.status_code == 400 and "message" in jsonResponse and "errorCode" in jsonResponse:
        errorMessage = u"%s: %s" % (errorMessage, jsonResponse["message"])

    raise Exception(errorMessage)


def load(protocolVersion):
    """ Функция выполняет подключение к SyncServer и выполнение загрузки справочников """
    log.info(u"Принудительная загрузка справочников")
    wdcommon.getClient().load(str(), wdcommon.getConfigInfo(int(protocolVersion)))


if __name__ == "__main__":
    serviceLock = ServiceLock('/linuxcash/cash/sync/bin/watchdog-load-pidfile', log)
    if not serviceLock.lock(True):
        exit(0)

    log.info(u'Запуск принудительной загрузки справочников')

    reconnectCount, reconnectPeriod = wdcommon.getReconnectParams(log)
    host, port, cashCode, protocolVersion = wdcommon.getSyncProperties(log)

    result = False
    for i in range(0, reconnectCount + 1):
        try:
            if checkLoadRequired(host, port, cashCode):
                load(protocolVersion)
            result = True
            break
        except Exception as e:
            log.error(u"В процессе выполнения операции произошла ошибка: %s" % e)

        if reconnectCount - i == 0:
            break

        log.warning(u"Повторная попытка через %s секунд. Осталось попыток: %s" % (reconnectPeriod, reconnectCount - i))
        sleep(reconnectPeriod)

    if result:
        log.info(u"Операция выполнена")
    else:
        log.warning(u"Не удалось выполнить принудительную загрузку справочников")

    serviceLock.unlock()
